| Title: | Estimation and Other Tools for Generalized Transmuted Models |
|---|---|
| Description: | Provide estimation and data generation tools for a generalization of the transmuted distributions discussed in Shaw and Buckley (2007). See <doi:10.48550/arXiv.0901.0434> for more information. |
| Authors: | Yolanda M. Gomez [aut], Hector W. Gomez [aut], Barry C. Arnold [aut], Diego I. Gallardo [aut, cre] |
| Maintainer: | Diego I. Gallardo <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0 |
| Built: | 2026-05-15 07:03:17 UTC |
| Source: | https://github.com/cran/gentransmuted |
choose.compound select a combination of baseline and compounding distributions in the class of compound distribution. See details for supported distributions.
choose.compound(x, type = "positive", criteria = "AIC")choose.compound(x, type = "positive", criteria = "AIC")
x |
the vector of values to be fitted. |
type |
Support of the x's. Avaliable options: positive (default), unit, real. |
criteria |
model selection criteria to be applied for the selection. Avaliable options: AIC (default, Akaike's information criteria) and BIC (Bayesian's information criteria). |
The compound distribution has cumulative distribution function
where is related to the baseline distribution and are related to compounding models.
For positive values, the options assessed for are exponential, gamma, log-normal, paretoII and Birnbaum-Saunders.
For unit values, the options for are beta and Kumaraswamy.
For real values, the options for are normal, logistic, Cauchy and Gumbel.
For and are assessed all the combinations among the exponentiated, exponentiated of second kind,
Marshall-Olkin, Marshall-Olkin of the second kind and
A list containing the following components:
coefficients |
A matrix with the estimates and standard errors. |
logLik |
The log-likelihood function evaluated in the estimated parameters |
AIC |
Akaike's Information Criterion |
BIC |
Bayesian's Information Criterion |
Yolanda M. Gomez, Diego I. Gallardo, Hector W. Gomez and Barry Arnold
set.seed(2100) y=rcompound(100, 1.2, 1.4, 1, 0.8, dist="exp", comp1="EXP", comp2="MO") choose.compound(y, type="positive")set.seed(2100) y=rcompound(100, 1.2, 1.4, 1, 0.8, dist="exp", comp1="EXP", comp2="MO") choose.compound(y, type="positive")
Density, distribution function, quantile function and random generation for the compound distributions.
dcompound(x, dist = "exp", comp1 = as.null(), comp2 = as.null(), gamma = 1, beta = 1, theta1 = 1, theta2 = 1, log = FALSE) pcompound(q, dist = "exp", comp1 = as.null(), comp2 = as.null(), gamma = 1, beta = 1, theta1 = 1, theta2 = 1, lower.tail = TRUE, log.p = FALSE) qcompound(p, dist = "exp", comp1 = as.null(), comp2 = as.null(), gamma = 1, beta = 1, theta1 = 1, theta2 = 1, lower.tail = TRUE, log.p = FALSE) rcompound(n, dist = "exp", comp1 = as.null(), comp2 = as.null(), gamma = 1, beta = 1, theta1 = 1, theta2 = 1)dcompound(x, dist = "exp", comp1 = as.null(), comp2 = as.null(), gamma = 1, beta = 1, theta1 = 1, theta2 = 1, log = FALSE) pcompound(q, dist = "exp", comp1 = as.null(), comp2 = as.null(), gamma = 1, beta = 1, theta1 = 1, theta2 = 1, lower.tail = TRUE, log.p = FALSE) qcompound(p, dist = "exp", comp1 = as.null(), comp2 = as.null(), gamma = 1, beta = 1, theta1 = 1, theta2 = 1, lower.tail = TRUE, log.p = FALSE) rcompound(n, dist = "exp", comp1 = as.null(), comp2 = as.null(), gamma = 1, beta = 1, theta1 = 1, theta2 = 1)
x, q
|
vector of quantiles. |
p |
vector of probabilities. |
n |
number of observations. If length(n) > 1, the length is taken to be the number required. |
dist |
baseline distribution. Avaliable options: exp (exponential), gamma, lnorm (log-normal), paretoII, bisa (Birnbaum-Saunders), lomax, beta, kumar (Kumaraswamy), norm (normal), logis (logistic), cauchy, gumbel. See details for parameterizations of these distributions. |
comp1, comp2
|
compounding distributions. Avaliable options: EXP (Exponentiated), EXP2 (Exponentiated of the second kind), MO (Marshall-Olkin), MO2 (Marshall-Olkin of the second kind), SB (Shaw and Buckley). |
gamma, beta
|
parameters for the baseline distribution. |
theta1, theta2
|
shape parameter for the comp1 and comp2 distributions, respectively. |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are |
The compound distribution has cumulative distribution function
where is related to dist, is related to comp1 and is related to comp2.
The support for depends on the baseline distribution. For exp, gamma, lnorm, paretoII, bisa and lomax, the support
is ; for beta and kumar is ; for norm, logis, cauchy and gumbel is .
The parameter space for and also depend on the baseline distribution. For exp, ; for gamma, paretoII, bisa, lomax,
beta and kumar ; for lnorm, norm, logis, cauchy and gumbel .
The parameter space for and depend on comp1 and comp2. For EXP, EXP2, MO and MO2 options
the corresponding parameter space is , whereas for SB option is . The probability density function for
each of the baseline distribution is given below.
exp
gamma
lnorm
paretoII
bisa
beta
kumar
For norm, logis, cauchy and gumbel, the probability density function is given by
where is given by
norm
logis
cauchy
gumbel
dcompound gives the density, pcompound gives the distribution function, qcompound gives the quantile function, and rcompound generates random deviates. The length of the result is determined by n for rcompound, and is the maximum of the lengths of the numerical arguments for the other functions. The numerical arguments other than n are recycled to the length of the result. Only the first elements of the logical arguments are used.
Yolanda M. Gomez, Diego I. Gallardo, Hector W. Gomez and Barry Arnold
set.seed(2100) y=rcompound(100, 1.2, 1.4, 1, 0.8, dist="exp", comp1="EXP", comp2="MO")set.seed(2100) y=rcompound(100, 1.2, 1.4, 1, 0.8, dist="exp", comp1="EXP", comp2="MO")
estimate.compound computes the maximum likelihood estimates for a compound distribution. See arguments for supported distributions.
estimate.compound(x, dist = "exp", comp1 = as.null(), comp2 = as.null(), est.var = TRUE)estimate.compound(x, dist = "exp", comp1 = as.null(), comp2 = as.null(), est.var = TRUE)
x |
the vector of values to be fitted. |
dist |
baseline distribution. Avaliable options: exp (exponential), gamma, lnorm (log-normal), paretoII, bisa (Birnbaum-Saunders), lomax, beta, kumar (Kumaraswamy), norm (normal), logis (logistic), cauchy, gumbel. See details for parameterizations of these distributions. |
comp1, comp2
|
compounding distributions. Avaliable options: EXP (Exponentiated), EXP2 (Exponentiated of the second kind), MO (Marshall-Olkin), MO2 (Marshall-Olkin of the second kind), SB (Shaw and Buckley). |
est.var |
Logical. If TRUE the standard errors are estimated. |
The parameterization for the different distributions is given in .
A list containing the following components:
coefficients |
A matrix with the estimates and standard errors. |
logLik |
The log-likelihood function evaluated in the estimated parameters |
AIC |
Akaike's Information Criterion |
BIC |
Bayesian's Information Criterion |
Yolanda M. Gomez, Diego I. Gallardo, Hector W. Gomez and Barry Arnold
set.seed(2100) y=rcompound(100, 1.2, 1.4, 1, 0.8, dist="exp", comp1="EXP", comp2="MO") estimate.compound(y, dist="exp", comp1="EXP", comp2="MO")set.seed(2100) y=rcompound(100, 1.2, 1.4, 1, 0.8, dist="exp", comp1="EXP", comp2="MO") estimate.compound(y, dist="exp", comp1="EXP", comp2="MO")
Density, distribution function, quantile function and random generation for the Exponentiated (EXP) and Exponentiated of the second kind (EXP2) distributions.
dEXP(x, alpha = 1, log = FALSE) pEXP(q, alpha = 1, lower.tail = TRUE, log.p = FALSE) qEXP(p, alpha = 1, lower.tail = TRUE, log.p = FALSE) rEXP(n, alpha = 1) dEXP2(x, alpha = 1, log = FALSE) pEXP2(q, alpha = 1, lower.tail = TRUE, log.p = FALSE) qEXP2(p, alpha = 1, lower.tail = TRUE, log.p = FALSE) rEXP2(n, alpha = 1)dEXP(x, alpha = 1, log = FALSE) pEXP(q, alpha = 1, lower.tail = TRUE, log.p = FALSE) qEXP(p, alpha = 1, lower.tail = TRUE, log.p = FALSE) rEXP(n, alpha = 1) dEXP2(x, alpha = 1, log = FALSE) pEXP2(q, alpha = 1, lower.tail = TRUE, log.p = FALSE) qEXP2(p, alpha = 1, lower.tail = TRUE, log.p = FALSE) rEXP2(n, alpha = 1)
x, q
|
vector of quantiles. |
p |
vector of probabilities. |
n |
number of observations. If length(n) > 1, the length is taken to be the number required. |
alpha |
shape parameter (by default is 1). |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are |
The EXP model has cumulative distribution function
whereas the EXP2 model has cumulative distribution function
dEXP and dEXP2 give the density, pEXP and pEXP2 give the distribution function, qEXP and qEXP2 give the quantile function, and rEXP and rEXP2 generate random deviates. The length of the result is determined by n for rcompound, and is the maximum of the lengths of the numerical arguments for the other functions. The numerical arguments other than n are recycled to the length of the result. Only the first elements of the logical arguments are used.
Yolanda M. Gomez, Diego I. Gallardo, Hector W. Gomez and Barry Arnold
set.seed(2100) y=rEXP(100, alpha = 1.2)set.seed(2100) y=rEXP(100, alpha = 1.2)
Density, distribution function, quantile function and random generation for the Marshall-Olkin (MO) and Marshall-Olkin of the second kind (MO2) distributions.
dMO(x, theta = 1, log = FALSE) pMO(q, theta = 1, lower.tail = TRUE, log.p = FALSE) qMO(p, theta = 1, lower.tail = TRUE, log.p = FALSE) rMO(n, theta = 1) dMO2(x, theta = 1, log = FALSE) pMO2(q, theta = 1, lower.tail = TRUE, log.p = FALSE) qMO2(p, theta = 1, lower.tail = TRUE, log.p = FALSE) rMO2(n, theta = 1)dMO(x, theta = 1, log = FALSE) pMO(q, theta = 1, lower.tail = TRUE, log.p = FALSE) qMO(p, theta = 1, lower.tail = TRUE, log.p = FALSE) rMO(n, theta = 1) dMO2(x, theta = 1, log = FALSE) pMO2(q, theta = 1, lower.tail = TRUE, log.p = FALSE) qMO2(p, theta = 1, lower.tail = TRUE, log.p = FALSE) rMO2(n, theta = 1)
x, q
|
vector of quantiles. |
p |
vector of probabilities. |
n |
number of observations. If length(n) > 1, the length is taken to be the number required. |
theta |
shape parameter (by default is 1). |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are |
The MO model has cumulative distribution function
whereas the MO2 model has cumulative distribution function
dEXP and dEXP2 give the density, pEXP and pEXP2 give the distribution function, qEXP and qEXP2 give the quantile function, and rEXP and rEXP2 generate random deviates. The length of the result is determined by n for rcompound, and is the maximum of the lengths of the numerical arguments for the other functions. The numerical arguments other than n are recycled to the length of the result. Only the first elements of the logical arguments are used.
Yolanda M. Gomez, Diego I. Gallardo, Hector W. Gomez and Barry Arnold
set.seed(2100) y=rMO(100, theta = 1.2)set.seed(2100) y=rMO(100, theta = 1.2)
Density, distribution function, quantile function and random generation for the Shaw and Buckley (SB) distribution.
dSB(x, lambda = 0, log = FALSE) pSB(q, lambda = 0, lower.tail = TRUE, log.p = FALSE) qSB(p, lambda = 0, lower.tail = TRUE, log.p = FALSE) rSB(n, lambda = 0)dSB(x, lambda = 0, log = FALSE) pSB(q, lambda = 0, lower.tail = TRUE, log.p = FALSE) qSB(p, lambda = 0, lower.tail = TRUE, log.p = FALSE) rSB(n, lambda = 0)
x, q
|
vector of quantiles. |
p |
vector of probabilities. |
n |
number of observations. If length(n) > 1, the length is taken to be the number required. |
lambda |
shape parameter (by default is 0). |
log, log.p
|
logical; if TRUE, probabilities p are given as log(p). |
lower.tail |
logical; if TRUE (default), probabilities are |
The SB model has cumulative distribution function
where and .
dSB gives the density, pSB gives the distribution function, qSB gives the quantile function, and rSB generates random deviates. The length of the result is determined by n for rcompound, and is the maximum of the lengths of the numerical arguments for the other functions. The numerical arguments other than n are recycled to the length of the result. Only the first elements of the logical arguments are used.
Yolanda M. Gomez, Diego I. Gallardo, Hector W. Gomez and Barry Arnold
set.seed(2100) y=rSB(100, lambda = 0.7)set.seed(2100) y=rSB(100, lambda = 0.7)